@@ -6,4 +6,7 @@ function (x, ...)
   
   cat ("\n Selected Coefficient Estimates: \n")
   print (cbind(Lambda=x$lam.vec,"# Selected"=x$num.pred, "CV Error"=x$mean.error),justify="centre")
+  
+  cat ("\n Optimal Lambda: \n")
+  print (x$lam.opt)
 }
