@@ -119,8 +119,9 @@
       LOGICAL :: SAME_SIGN
       REAL(KIND=DBLE) :: CRITERION = TEN**(-5),EPSILON = TEN**(-8)
       REAL(KIND=DBLE) :: A,B,C,LAMBDA,L1,OBJECTIVE,PENALTY,S,SLOPE
-      REAL(KIND=DBLE), DIMENSION(CASES) :: ESTIMATE,Y
-      REAL(KIND=DBLE), DIMENSION(PREDICTORS+1,CASES) :: X
+      REAL(KIND=DBLE), DIMENSION(CASES) :: Y
+      REAL(KIND=DBLE), DIMENSION(PREDICTORS) :: ESTIMATE
+      REAL(KIND=DBLE), DIMENSION(PREDICTORS,CASES) :: X
       INTEGER, DIMENSION(SIZE(Y)+1) :: PERMUTATION
       REAL(KIND=DBLE), DIMENSION(SIZE(X,1)) :: FDD,ZDD
       REAL(KIND=DBLE), DIMENSION(SIZE(Y)) :: R
@@ -339,8 +340,9 @@
       REAL(KIND=DBLE) :: A,B,C,DL2,LAMBDA,L2,OBJECTIVE,PENALTY,NEW_OBJECTIVE
       REAL(KIND=DBLE) :: LEFT_L2,LEFT_OBJECTIVE,LEFT_PENALTY,LEFT_ROOT
       REAL(KIND=DBLE) :: RIGHT_L2,RIGHT_OBJECTIVE,RIGHT_PENALTY,RIGHT_ROOT
-      REAL(KIND=DBLE), DIMENSION(CASES) :: ESTIMATE,Y
-      REAL(KIND=DBLE), DIMENSION(PREDICTORS+1,CASES) :: X_INPUT
+      REAL(KIND=DBLE), DIMENSION(CASES) :: Y
+      REAL(KIND=DBLE), DIMENSION(PREDICTORS) :: ESTIMATE
+      REAL(KIND=DBLE), DIMENSION(PREDICTORS,CASES) :: X_INPUT
       REAL(KIND=DBLE), DIMENSION(SIZE(X_INPUT,1)) :: SUM_X_SQUARES
       REAL(KIND=DBLE), DIMENSION(SIZE(Y)) :: LEFT_R,R,RIGHT_R
       REAL(KIND=DBLE), DIMENSION(SIZE(X_INPUT,2),SIZE(X_INPUT,1)) :: X
